package com.pjilisense.flxai.controller;

import com.pjilisense.flxai.base.constant.Constant;
import com.pjilisense.flxai.page.PageData;
import com.pjilisense.flxai.utils.ExcelUtils;
import com.pjilisense.flxai.utils.Result;
import com.pjilisense.flxai.dto.MyDigitalHumanDTO;
import com.pjilisense.flxai.excel.MyDigitalHumanExcel;
import com.pjilisense.flxai.service.MyDigitalHumanService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * ${comments}
 *
 * @author liushujing liushujing@philisense.com
 * @since 1.0.0 2025-02-26
 */
@RestController
@RequestMapping(Constant.BASE_PATH+"mydigitalhuman")
@Api(tags="${comments}")
public class MyDigitalHumanController {

    private static Logger logger = LoggerFactory.getLogger(MyDigitalHumanController.class);

    @Autowired
    private MyDigitalHumanService myDigitalHumanService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String", dataTypeClass =String.class) ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String", dataTypeClass =String.class)
    })
    @RequiresPermissions("robot:mydigitalhuman:page")
    public Result<PageData<MyDigitalHumanDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<MyDigitalHumanDTO> page = myDigitalHumanService.page(params);

        return new Result<PageData<MyDigitalHumanDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    @RequiresPermissions("robot:mydigitalhuman:info")
    public Result<MyDigitalHumanDTO> get(@PathVariable("id") Long id){
        MyDigitalHumanDTO data = myDigitalHumanService.get(id);

        return new Result<MyDigitalHumanDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    @LogOperation("保存")
    @RequiresPermissions("robot:mydigitalhuman:save")
    public Result save(@RequestBody MyDigitalHumanDTO dto){
        //效验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        myDigitalHumanService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    @LogOperation("修改")
    @RequiresPermissions("robot:mydigitalhuman:update")
    public Result update(@RequestBody MyDigitalHumanDTO dto){
        //效验数据
        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        myDigitalHumanService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    @LogOperation("删除")
    @RequiresPermissions("robot:mydigitalhuman:delete")
    public Result delete(@RequestBody Long[] ids){
        //效验数据
        AssertUtils.isArrayEmpty(ids, "id");

        myDigitalHumanService.delete(ids);

        return new Result();
    }

    @GetMapping("export")
    @ApiOperation("导出")
    @LogOperation("导出")
    @RequiresPermissions("robot:mydigitalhuman:export")
    public void export(@ApiIgnore @RequestParam Map<String, Object> params, HttpServletResponse response) throws Exception {
        List<MyDigitalHumanDTO> list = myDigitalHumanService.list(params);

        ExcelUtils.exportExcelToTarget(response, null, "${comments}", list, MyDigitalHumanExcel.class);
    }

}